# XGBImputer

<div class="termy">

XGBImputer is an effort to implement the concepts of the MissForest algorithm proposed by Daniel J. Stekhoven and Peter Bühlmann[1] in 2012, but leveraging the robustness and predictive power of the XGBoost[2] algorithm released in 2014.

The package also aims to simplify the process of imputing categorical values in a scikit-learn[3] compatible way.

</div>

## Installation

<div class="termy">

```console
$ pip install xgbimputer
```

</div>

## License

<div class="termy">

This project is licensed under the terms of the [Apache-2](https://github.com/leonardodepaula/xgbimputer/blob/master/LICENSE) license.

</div>

## References

<div class="termy">

* [1] [Daniel J. Stekhoven and Peter Bühlmann. "MissForest—non-parametric missing value imputation for mixed-type data."](https://academic.oup.com/bioinformatics/article/28/1/112/219101)

* [2] [XGBoost](https://xgboost.ai/)

* [3] [scikit-learn](https://scikit-learn.org/)

</div>
